import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignatureBuilder.signatureFor;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;
 
import java.text.SimpleDateFormat;
import java.util.Date;
 
import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
 
public class SignerOrder {
	public static final String API_KEY = "<YOUR API KEY HERE>";
	public static final String API_URL = "https://sandbox.e-signlive.com/api"; // USE https://apps.e-signlive.com/api FOR PRODUCTION
 
	private static final String DATE_FORMAT = "EEE, d MMM yyyy HH:mm:ss Z";
 
	public static void main(String[] args) {
		SimpleDateFormat format = new SimpleDateFormat(DATE_FORMAT);
 
		EslClient eslClient = new EslClient(API_KEY, API_URL);
 
		DocumentPackage documentPackage = newPackageNamed("Policy " + format.format(new Date()))
			.withSigner(newSignerWithEmail("signer1@xyz.com")
				.withFirstName("FirstNameSigner1")
				.withLastName("LastNameSigner1")
				.signingOrder(1))
			.withSigner(newSignerWithEmail("signer2@xyz.com")
				.withFirstName("FirstNameSigner2")
				.withLastName("LastNameSigner2")
				.signingOrder(2))
			.withSigner(newSignerWithEmail("signer3@xyz.com")
				.withFirstName("FirstNameSigner3")
				.withLastName("LastNameSigner3")
				.signingOrder(2))
			.withSigner(newSignerWithEmail("signer4@xyz.com")
				.withFirstName("FirstNameSigner4")
				.withLastName("LastNameSigner4")
				.signingOrder(3))
			.withDocument(newDocumentWithName("First Document")
				.fromFile("res/document.pdf")
				.withSignature(signatureFor("signer1@xyz.com")
					.onPage(0)
					.atPosition(100, 200))
				.withSignature(signatureFor("signer2@xyz.com")
					.onPage(0)
					.atPosition(100, 400))
				.withSignature(signatureFor("signer3@xyz.com")
					.onPage(0)
					.atPosition(100, 600))						
				.withSignature(signatureFor("signer4@xyz.com")
					.onPage(0)
					.atPosition(100, 800)))
			.build();
 
		// Issue the request to the e-SignLive server to create the DocumentPackage
		PackageId packageId = eslClient.createPackage(documentPackage);
 
		// Send the package to be signed by the participants
		eslClient.sendPackage(packageId);
	}
}